@@ -268,6 +268,9 @@ def type_info(np_type):
         # 80) but in calculations nexp in fact appears to be 11 as for float64
         ret.update(dict(width=width))
         return ret
+    if vals == (105, 11, 16): # correctly detected double double
+        ret.update(dict(nmant=nmant, nexp=nexp, width=width))
+        return ret
     # Oh dear, we don't recognize the type information.  Try some known types
     # and then give up. At this stage we're expecting exotic longdouble or
     # their complex equivalent.
