@@ -680,6 +680,10 @@ class EcatImageArrayProxy(object):
     def shape(self):
         return self._shape
 
+    @property
+    def ndim(self):
+        return len(self.shape)
+
     @property
     def is_proxy(self):
         return True
